Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'core/Menu/MenuAdmin.php')
-rw-r--r--core/Menu/MenuAdmin.php29
1 files changed, 16 insertions, 13 deletions
diff --git a/core/Menu/MenuAdmin.php b/core/Menu/MenuAdmin.php
index 9c05734e5f..c8273ed16b 100644
--- a/core/Menu/MenuAdmin.php
+++ b/core/Menu/MenuAdmin.php
@@ -8,6 +8,7 @@
*/
namespace Piwik\Menu;
+use Piwik\Development;
use Piwik\Piwik;
/**
@@ -33,7 +34,7 @@ use Piwik\Piwik;
class MenuAdmin extends MenuAbstract
{
/**
* See {@link add()}. Adds a new menu item to the development section of the admin menu.
* @param string $menuName
* @param array $url
* @param int $order
@@ -41,13 +42,13 @@ class MenuAdmin extends MenuAbstract
* @api
* @since 2.5.0
*/
- public function addDevelopmentItem($menuName, $url, $order = 50, $tooltip = false)
+ public function addPersonalItem($menuName, $url, $order = 50, $tooltip = false)
{
- $this->addItem('CoreAdminHome_MenuDevelopment', $menuName, $url, $order, $tooltip);
+ $this->addItem('UsersManager_MenuPersonal', $menuName, $url, $order, $tooltip);
}
/**
- * See {@link add()}. Adds a new menu item to the diagnostic section of the admin menu.
+ * See {@link add()}. Adds a new menu item to the development section of the admin menu.
* @param string $menuName
* @param array $url
* @param int $order
@@ -55,13 +56,15 @@ class MenuAdmin extends MenuAbstract
* @api
* @since 2.5.0
*/
- public function addDiagnosticItem($menuName, $url, $order = 50, $tooltip = false)
+ public function addDevelopmentItem($menuName, $url, $order = 50, $tooltip = false)
{
- $this->addItem('CoreAdminHome_MenuDiagnostic', $menuName, $url, $order, $tooltip);
+ if (Development::isEnabled()) {
+ $this->addItem('CoreAdminHome_MenuDevelopment', $menuName, $url, $order, $tooltip);
+ }
}
/**
- * See {@link add()}. Adds a new menu item to the platform section of the admin menu.
+ * See {@link add()}. Adds a new menu item to the diagnostic section of the admin menu.
* @param string $menuName
* @param array $url
* @param int $order
@@ -69,13 +72,13 @@ class MenuAdmin extends MenuAbstract
* @api
* @since 2.5.0
*/
- public function addPlatformItem($menuName, $url, $order = 50, $tooltip = false)
+ public function addDiagnosticItem($menuName, $url, $order = 50, $tooltip = false)
{
- $this->addItem('CorePluginsAdmin_MenuPlatform', $menuName, $url, $order, $tooltip);
+ $this->addItem('CoreAdminHome_MenuDiagnostic', $menuName, $url, $order, $tooltip);
}
/**
- * See {@link add()}. Adds a new menu item to the settings section of the admin menu.
+ * See {@link add()}. Adds a new menu item to the platform section of the admin menu.
* @param string $menuName
* @param array $url
* @param int $order
@@ -83,9 +86,9 @@ class MenuAdmin extends MenuAbstract
* @api
* @since 2.5.0
*/
- public function addSettingsItem($menuName, $url, $order = 50, $tooltip = false)
+ public function addPlatformItem($menuName, $url, $order = 50, $tooltip = false)
{
- $this->addItem('General_Settings', $menuName, $url, $order, $tooltip);
+ $this->addItem('CorePluginsAdmin_MenuPlatform', $menuName, $url, $order, $tooltip);
}
/**
@@ -99,7 +102,7 @@ class MenuAdmin extends MenuAbstract
*/
public function addManageItem($menuName, $url, $order = 50, $tooltip = false)
{
- $this->addItem('CoreAdminHome_Administration', $menuName, $url, $order, $tooltip);
+ $this->addItem('CoreAdminHome_MenuManage', $menuName, $url, $order, $tooltip);
}
/**
@@ -33,7 +34,7 @@ use Piwik\Piwik;
{
/**
- * See {@link add()}. Adds a new menu item to the development section of the admin menu.
+ * See {@link add()}. Adds a new menu item to the manage section of the user menu.
* @param string $menuName
* @param array $url